# Archive Warrior
<div align="center">
  <img src="https://wiki.archiveteam.org/images/e/e0/Warrior-web-screenshot.png" />
</div>

## Descrizione
[Sito ufficiale](https://warrior.archiveteam.org/) - [Repo (Github)](https://github.com/ArchiveTeam/warrior-dockerfile)

Archive Warrior è nodo per aiutare l'[Archive Team](https://archive.org/):
- Con poche risorse locali si può aiutare a salvare un pò di internet
- Chiunque almeno una volta ha usato archive.org per ritrovare qualcosa, adesso sapete come aiutare (se volete)

## Struttura file e cartelle
```
/home/
└── docker/
    └── archive-warrior/
        ├── .env
        └── docker-compose.yml
```

* `.env` - file contenenti le variabili environment per il docker-compose
* `docker-compose.yml` - file usato per creare il container

**N.B. Tutti i file e le cartelle devono essere creati a mano.**

## Esempi
Semplice esempio per iniziare ad usare subito il container

### docker-compose
`docker-compose.yml`
```yml
version: "3.5"
services:
  archivewarrior:
    container_name: archive-warrior
    image: archiveteam/warrior-dockerfile
    security_opt:
      - no-new-privileges:true
    networks:
      - custom-bridge
    restart: unless-stopped
    ports:
      - ${ARCWAR_WEBUI_PORT:-8001}:8001
    env_file: .env
    cpus: 2 # usa massimo 2 core del vostro processore
    mem_limit: 3072m # usa massimo 3GB di RAM

networks:
  custom-bridge:
    name: custom-bridge
    driver: bridge
```

`.env`
```bash
# Generale
ARCWAR_WEBUI_PORT=8001

# Archive Warrior
DOWNLOADER=cambiamiperfavore # e.g. DOWNLOADER=PincoPallino11
WORKER_ID=cambiamiperfavore  #      WORKER_ID=PincoPallino11
SELECTED_PROJECT=auto
CONCURRENT_ITEMS=3
```

## Aggiornamento
### Automatico
Se usate [watchtower](../watchtower) il container si aggiorna automaticamente

### Manuale
1. `docker-compose pull`
2. `docker-compose up -d`
3. `docker image prune`

## Backup e ripristino
### Backup
Usate [borg](../borg_backup) per fare i backup giornalieri dell'intera cartella `archive-warrior`

### Ripristino
Per una maggiore spiegazione sui passaggi da fare, controllate [qua](../borg_backup#user-content-controllare-la-cartella-dei-backup)
1. fermare il container `docker-compose down`
2. cancellare l'intera cartella `archive-warrior`
3. dal backup copiare la cartella `archive-warrior`
4. far ripartire il container `docker-compose up -d`

## Todo
Implementare:
- reverse proxy: **[caddy](https://caddyserver.com/)** o **[traefik](https://doc.traefik.io/traefik/)**
