# Folding@Home
<div align="center">
  <img src="https://www.bleepstatic.com/images/news/software/f/folding-at-home/coronavirus/folding-at-home.jpg" />
</div>

## Descrizione
[Sito ufficiale](https://foldingathome.org/) - [Repo (Github)](https://github.com/linuxserver/docker-foldingathome) - [Docs](https://docs.linuxserver.io/images/docker-foldingathome)

Folding@Home è un progetto di calcolo distribuito per aiutare la ricerca medica:
- Simulazione del comportamento delle proteine (e non solo) relative a malattie degenerative, infettive e molto altro
- Supporto al calcolo tramite CPU e/o GPU (la scelta è vostra)

> **P.S è un progetto a cui tengo particolarmente, quindi anche se avete un computer vecchio che non usate, questo è il progetto perfetto per renderlo di nuovo utile a tutti e per tutti**

## Struttura file e cartelle
```
/home/
└── docker/
    └── folding@home/
            ├── config/
            ├── .env
            └── docker-compose.yml
```

* `config/` - cartella dove risiedono i dati che servono a folding@home
* `.env` - file contenenti le variabili environment per il docker-compose
* `docker-compose.yml` - file usato per creare il container

**N.B. Tutti i file e le cartelle devono essere creati a mano.**

## Esempi
Semplice esempio per iniziare ad usare subito il container

### docker-compose
`docker-compose.yml`
```yml
version: "3.5"
services:
  fah:
    container_name: linuxserver-fah
    image: ghcr.io/linuxserver/foldingathome
    security_opt:
      - no-new-privileges:true
    networks: 
      - custom-bridge
    restart: unless-stopped
    ports:
      - ${FAH_WEBUI_PORT:-7396}:7396
    env_file: .env
    volumes:
      - ${FAH_DATA:-/home/docker/folding@home/config}:/config
    healthcheck: # se modificate la porta dell'interfaccia web, ricordatevi di cambiarla anche qua sotto
      test: ["CMD", "curl", "-Ssf", http://localhost:7396"]
      interval: 1m30s
      timeout: 10s
      retries: 3
      start_period: 1m

networks:
  custom-bridge:
    name: custom-bridge
    driver: bridge
```

`.env`
```bash
# Generale
FAH_WEBUI_PORT=7396
FAH_DATA=/home/docker/fah/data

# Folding@Home
TZ=Europe/Amsterdam
```

## Reverse proxy
Ancora non ho previsto l'uso di un reverse proxy (Vedi [Todo](#Todo))

## Aggiornamento
### Automatico
Usando [watchtower](../watchtower) il container si aggiorna automaticamente

### Manuale
1. `docker-compose pull`
2. `docker-compose up -d`
3. `docker image prune`

## Backup e ripristino
### Backup
Usate [borg](../borg_backup) per fare i backup giornalieri dell'intera cartella `folding@home`

### Ripristino
Per una maggiore spiegazione sui passaggi da fare, controllate [qua](../borg_backup#user-content-controllare-la-cartella-dei-backup)
1. fermare il container `docker-compose down`
2. cancellare l'intera cartella `folding@home`
3. dal backup copiare la cartella `folding@home`
4. far ripartire il container `docker-compose up -d`

## Todo
Implementare:
- reverse proxy: **[caddy](https://caddyserver.com/)** o **[traefik](https://doc.traefik.io/traefik/)**
